Getting Started
===============

This is a TL-DR guide to get you started with Storlet experimentation
as fast as possible.


System Requirements
-------------------

Ubuntu Server 14.04 with total disk of 10Gb.
A disposal VM is always a good idea.


Installation Guide
-------------------

.. include:: s2aio_dev_host_include.rst

For more information please refer to `"s2aio" <http://storlets.readthedocs.io/en/latest/s2aio.html>`__.

Writing Deploying and Running a Storlet
---------------------------------------

Browse through the StorletSamples directory so see storlet code examples,
and through the tests/functional to see samples of deploying and invoking
a storlet.
